@@ -248,10 +248,11 @@ class PageObject(object):
         return self
 
 
-    def get_attribute(self, attribute):
-        self.logger.info('getting attribute "{}" of {}'.format(attribute, self._log_id_short))
-        self.logger.debug('getting attribute "{}" of page object; {}'.format(attribute, self._log_id_long))
-        return self.find(log=False).get_attribute(attribute)
+    def get_attribute(self, attribute, log=True):
+        if log:
+            self.logger.info('getting attribute "{}" of {}'.format(attribute, self._log_id_short))
+            self.logger.debug('getting attribute "{}" of page object; {}'.format(attribute, self._log_id_long))
+        return self.find(log=log).get_attribute(attribute)
 
 
     def move_to(self):
